@@ -8,7 +8,7 @@
 #' }
 "country_codes"
 
-#' Maximum Temperature for Station CA003076680
+#' Daily data for Station CA003076680
 #'
 #' @format ## `CA003076680`
 #' A 'ghcn-daily' object, i.e. table 7,574 x 8:
@@ -23,6 +23,21 @@
 #' @source <https://www.countrycallingcodes.com/iso-country-codes/europe-codes.php>
 "CA003076680"
 
+#' Daily data for Station USC00010655
+#'
+#' @format ## `USC00010655`
+#' A 'ghcn-daily' object, i.e. table 7,809 x 8:
+#' \describe{
+#'   \item{date}{Date of measurment}
+#'   \item{station}{Station name, i.e. 'USC00010655'}
+#'   \item{tmax}{Maximum temperature}
+#'   \item{tmin}{Minimum temperature}
+#'   \item{prcp}{Total precipitation}
+#'   \item{*_flag}{Flags for the measurments}
+#' }
+#' @source <https://www.countrycallingcodes.com/iso-country-codes/europe-codes.php>
+"USC00010655"
+
 #' Elevation of the GHCNd Stations
 #'
 #' @format ## `europe_codes`
